package eu.mhsl.craftattack.spawn.varo.appliances.metaGameplay.teams;

import eu.mhsl.craftattack.spawn.core.util.text.DisconnectInfo;
import org.bukkit.Bukkit;
import org.bukkit.OfflinePlayer;
import org.jetbrains.annotations.Nullable;

import java.util.List;
import java.util.Objects;
import java.util.UUID;

public class VaroTeam {
    public static class Member {
        public final OfflinePlayer player;
        public boolean isDead;

        public Member(UUID playerId, boolean isDead) {
            this.player = Bukkit.getOfflinePlayer(playerId);
            this.isDead = isDead;
        }
    }

    public final List<Member> members;
    public final UUID teamUuid;
    public final String name;
    public final String color;

    public VaroTeam(List<Member> members, String name, String color) {
        this.teamUuid = UUID.randomUUID();
        this.members = members;
        this.name = name;
        this.color = color;
    }

    public boolean isTeamDead() {
        return this.members.stream().allMatch(member -> member.isDead);
    }

    public boolean hasMember(UUID uuid) {
        return this.members.stream()
            .anyMatch(member -> member.player.getUniqueId().equals(uuid));
    }

    public @Nullable Member getMemberById(UUID uuid) {
        return this.members.stream()
            .filter(member -> member.player.getUniqueId().equals(uuid))
            .findFirst()
            .orElse(null);
    }

    public void kickTeam() {
        this.kickTeam(new DisconnectInfo(
            "Unbekannter Fehler",
            "Verbindung wurde aufgrund eines unbekannten Grundes getrennt",
            "Falls du denkst, dass dies ein Fehler ist, melde dich bei einem Admin!",
            this.teamUuid
        ));
    }

    public void kickTeam(DisconnectInfo disconnectInfo) {
        this.members.stream()
            .map(member -> Bukkit.getPlayer(member.player.getUniqueId()))
            .filter(Objects::nonNull)
            .forEach(player -> player.kick(disconnectInfo.getComponent()));
    }
}
